==> Arm_Performance_Studio_2025.6_linux_x86-64.tgz: Arm_Performance_Studio_2025.6/streamline/gator/daemon/metrics/group_generator.hpp <==
/* Copyright (C) 2023-2025 by Arm Limited (or its affiliates). All rights reserved. */

#pragma once

#include "lib/Span.h"
#include "metrics/definitions.hpp"

#include <cstddef>
#include <cstdint>
#include <functional>
#include <string_view>
#include <unordered_set>
#include <vector>

namespace metrics {
    using score_t = std::uint64_t;

    struct combination_t {
        std::unordered_set<metric_events_set_t const *> contains_sets;
        std::unordered_set<std::uint16_t> event_codes;
        std::uint16_t ebs_ratio;
        metric_arch_t arch = metric_arch_t::any;
        bool uses_cycles;

        combination_t(std::unordered_set<metric_events_set_t const *> contains_sets,
                      std::unordered_set<std::uint16_t> event_codes,
                      std::uint16_t ebs_ratio,
                      metric_arch_t arch,
                      bool uses_cycles)
            : contains_sets(std::move(contains_sets)),
              event_codes(std::move(event_codes)),
              ebs_ratio(ebs_ratio),
              arch(arch),
              uses_cycles(uses_cycles)
        {
        }
    };

    [[nodiscard]] metric_cpu_event_map_entry_t const * find_events_for_cset(std::string_view cset_id);

    [[nodiscard]] std::vector<combination_t> make_combinations(
        bool ebs_mode,
        std::size_t max_events,
        lib::Span<std::reference_wrapper<metrics::metric_events_set_t const> const> events,
        std::function<bool(metric_events_set_t const &)> const & filter_predicate = [](auto const &) { return true; });
}

==> Arm_Performance_Studio_2025.7_linux_x86-64.tgz: Arm_Performance_Studio_2025.7/streamline/gator/daemon/metrics/group_generator.hpp <==
/* Copyright (C) 2023-2025 by Arm Limited (or its affiliates). All rights reserved. */

#pragma once

#include "lib/Span.h"
#include "metrics/definitions.hpp"

#include <cstddef>
#include <cstdint>
#include <functional>
#include <string_view>
#include <unordered_set>
#include <vector>

namespace metrics {
    using score_t = std::uint64_t;

    struct combination_t {
        std::unordered_set<metric_events_set_t const *> contains_sets;
        std::unordered_map<std::uint16_t, std::uint16_t> event_code_to_freq_multiplier;
        metric_arch_t arch = metric_arch_t::any;
        bool uses_cycles;

        combination_t(std::unordered_set<metric_events_set_t const *> contains_sets,
                      std::unordered_map<std::uint16_t, std::uint16_t> event_code_to_freq_multiplier,
                      metric_arch_t arch,
                      bool uses_cycles)
            : contains_sets(std::move(contains_sets)),
              event_code_to_freq_multiplier(std::move(event_code_to_freq_multiplier)),
              arch(arch),
              uses_cycles(uses_cycles)
        {
        }
    };

    [[nodiscard]] metric_cpu_event_map_entry_t const * find_events_for_cset(std::string_view cset_id);

    [[nodiscard]] std::vector<combination_t> make_combinations(
        std::size_t max_events,
        lib::Span<std::reference_wrapper<metrics::metric_events_set_t const> const> events,
        std::function<bool(metric_events_set_t const &)> const & filter_predicate = [](auto const &) { return true; });
}
